import attr
from typing import Dict, Union


@attr.dataclass
class DataWilayah:
    rt_rw: str
    desa: str

    def todict(self) -> Dict[str, str]:
        if "/" not in self.rt_rw:
            raise ValueError(f"isi rt rw dengan format rt/rw")
        elif len(self.rt_rw) != "7":
            raise ValueError(f"rt dan rw masing2 harus 3 digit")
        rt, rw = self.rt_rw.split("/")
        return {
            "desa": self.desa,
            "kecamatan": self.desa[0:7],
            "kota": self.desa[0:4],
            "provinsi": self.desa[0:2],
            "rt": rt,
            "rw": rw,
        }



import attr
from typing import Optional

from .enums import KondisiPekerjaan, PekerjaanUtama


@attr.dataclass
class DataPekerjaan:
    kondisi_pekerjaan: KondisiPekerjaan
    pekerjaan_utama: Optional[PekerjaanUtama] = None
    pekerjaan_utama_comment: Optional[str] = None
    jaminan_sosial_ketenagakerjaan: Optional[str] = None

    def todict(self):
        data = {"I.P201": self.kondisi_pekerjaan.value}
        if self.kondisi_pekerjaan != KondisiPekerjaan.BEKERJA:
            return data
        assert self.pekerjaan_utama
        data["I.P202"] = self.pekerjaan_utama.value
        if self.pekerjaan_utama == PekerjaanUtama.LAINNYA:
            assert self.pekerjaan_utama_comment
            data["I.P202"] = self.pekerjaan_utama_comment
        if self.jaminan_sosial_ketenagakerjaan:
            data["I.P203"] = self.jaminan_sosial_ketenagakerjaan
        else:
            data["I.P203"] = "2"
        return data



import logging
import tkinter as tk
from tkinter.filedialog import asksaveasfilename
from tkinter.messagebox import showerror, showinfo, showwarning

import adbutils
from uiautomator2.init import Initer

from sdgs_tools.aplikasi_sdgs.excel import make_template_individu
from sdgs_tools.aplikasi_sdgs.excel import make_template_keluarga

# from sdgs_tools.aplikasi_sdgs.export import export_individu as _export_individu
# from sdgs_tools.aplikasi_sdgs.export import export_keluarga as _export_keluarga

from .export_individu import ExportIndividuWindow
from .export_keluarga import ExportKeluargaWindow


class AplikasiTab(tk.Frame):
    def __init__(self, master: tk.Frame, **kw):
        super().__init__(master, bg="#CCC", width=500, height=500, **kw)
        self.pack(expand=True, fill="both", side="right")
        self.label_info = tk.Label(
            self,
            text="Fitur ini untuk meng eksport data dari aplikasi sdgs android",
        )
        self.label_info.grid(row=0, column=0, columnspan=2)
        self.template_individu_button = tk.Button(
            self,
            text="Buat Template Individu",
            command=self.generate_template_individu,
        )
        self.template_individu_button.grid(row=1, column=0)
        self.template_keluarga_button = tk.Button(
            self,
            text="Buat Template Keluarga",
            command=self.generate_template_keluarga,
        )
        self.template_keluarga_button.grid(row=1, column=1)

        self.init_device_button = tk.Button(
            self,
            text="Inisiasi Perangkat Android",
            command=self.init_device,
        )
        self.init_device_button.grid(row=2, column=0)
        self.eksport_individu_button = tk.Button(
            self,
            text="Eksport Data Individu",
            command=ExportIndividuWindow,
        )
        self.eksport_individu_button.grid(row=3, column=0)
        self.eksport_keluarga_button = tk.Button(
            self,
            text="Eksport Data Keluarga",
            command=ExportKeluargaWindow,
        )
        self.eksport_keluarga_button.grid(row=3, column=1)

    @staticmethod
    def generate_template_individu():
        files = [
            ("Excel 2010+", "*.xlsx"),
        ]
        filepath = asksaveasfilename(filetypes=files, defaultextension=files)
        if not filepath:
            showwarning("Nama", "mohon tentukan nama dan tempat menyimpan file")
            return
        try:
            make_template_individu(filepath)
            showinfo("Sukses", f"Berhasil membuat template individu\n{filepath}")
        except Exception as e:
            showerror("Error", f"Gagal membuat template individu karena {repr(e)}")

    @staticmethod
    def generate_template_keluarga():
        files = [
            ("Excel 2010+", "*.xlsx"),
        ]
        filepath = asksaveasfilename(filetypes=files, defaultextension=files)
        if not filepath:
            showwarning("Nama", "mohon tentukan nama dan tempat menyimpan file")
            return
        try:
            make_template_keluarga(filepath)
            showinfo("Sukses", "Berhasil membuat template keluarga")
        except Exception as e:
            showerror("Error", f"Gagal membuat template keluarga karena {repr(e)}")

    @staticmethod
    def init_device():
        for device in adbutils.adb.iter_device():
            init = Initer(device, loglevel=logging.INFO)
            init.install()



import attr
from datetime import date
from typing import Dict, Optional

from sdgs_tools.dashboard.utils import date_to_str
from .enums import Agama
from .enums import StatusPernikahan


@attr.dataclass
class DataIndividu:
    no_kk: str
    nik: str
    nama: str
    jenis_kelamin: str
    tempat_lahir: str
    tanggal_lahir: date
    usia: str
    status_pernikahan: StatusPernikahan
    agama: Agama
    suku: str
    warganegara: str
    nomor_hp: str
    aktif_internet: str
    kecepatan_internet: str
    agama_comment: Optional[str] = None
    akses_melalui: Optional[str] = None
    usia_menikah: Optional[str] = None
    nomor_whatsapp: Optional[str] = None
    alamat_email: Optional[str] = None
    alamat_facebook: Optional[str] = None
    alamat_twitter: Optional[str] = None
    alamat_instagram: Optional[str] = None

    def todict(self) -> Dict[str, str]:
        data = {
            "no_kk": self.no_kk,
            "nik": self.nik,
            "I.P103": self.nama,
            "I.P104": "2" if self.jenis_kelamin == "P" else "1",
            "I.P105": self.tempat_lahir,
            "I.P106": date_to_str(self.tanggal_lahir),
            "I.P107": self.usia,
            "I.P108": "2",
            "I.P110": self.agama.value,
            "I.P111": self.suku,
            "I.P112": "2" if self.warganegara == "WNA" else "1",
            "I.P113": self.nomor_hp,
        }
        if self.status_pernikahan != StatusPernikahan.BELUM_KAWIN:
            assert self.usia_menikah
            data["I.P109"] = self.usia_menikah
        if self.nomor_whatsapp:
            data["I.P114"] = self.nomor_whatsapp
        if self.alamat_email:
            data["I.P115"] = self.alamat_email
        if self.alamat_facebook:
            data["I.P116"] = self.alamat_facebook
        if self.alamat_twitter:
            data["I.P117"] = self.alamat_twitter
        if self.alamat_instagram:
            data["I.P118"] = self.alamat_instagram
        return data



from enum import Enum


class Agama(Enum):
    ISLAM = "1"
    KRISTEN = "2"
    KATOLIK = "3"
    HINDU = "4"
    BUDHA = "5"
    KHONGHUCU = "6"
    LAINNYA = "other"


class KondisiPekerjaan(Enum):
    BERSEKOLAH = 1
    IBU_RUMAH_TANGGA = 2
    TIDAK_BEKERJA = 3
    SEDANG_MENCARI_PEKERJAAN = 4
    BEKERJA = 5


class PekerjaanUtama(Enum):
    PETANI_PEMILIK_LAHAN = "1"
    PETANI_PENYEWA = "2"
    BURUH_TANI = "3"
    NELAYAN_PEMILIK_KAPAL = "4"
    NELAYAN_PENYEWA_KAPAL = "5"
    BURUH_NELAYAN = "6"
    GURU = "7"
    GURU_AGAMA = "8"
    PEDAGANG = "9"
    PENGOLAHAN_INDUSTRI = "10"
    PNS = "11"
    TNI = "12"
    PERANGKAT_DESA = "13"
    PEGAWAI_KANTOR_DESA = "14"
    TKI = "15"
    LAINNYA = "other"


class StatusPernikahan(Enum):
    BELUM_KAWIN = "1"
    KAWIN = "2"
    CERAI_HIDUP = "3"
    CERAI_MATI = "4"



import tkinter as tk
from tkinter.filedialog import askopenfilename
from tkinter.messagebox import showerror, showinfo, showwarning

from sdgs_tools.aplikasi_sdgs.export import export_keluarga as _export_keluarga


class ExportKeluargaWindow(tk.Toplevel):
    def __init__(self, master=None):
        super().__init__(master=master, width=400, height=400)
        self.title("Eksport Keluarga")
        self.label_info = tk.Label(
            self,
            text="Eksport data keluarga",
        )
        self.label_info.grid(row=0, column=0, columnspan=3)
        # Baris
        self.baris_label = tk.Label(self, text="Baris")
        self.baris_label.grid(row=1, column=0)
        self.baris = tk.StringVar(self, "1")
        self.baris_entry = tk.Entry(self, textvariable=self.baris)
        self.baris_entry.grid(row=1, column=1)
        self.baris_info_button = tk.Button(self, text="?", command=self.info_baris)
        self.baris_info_button.grid(row=1, column=2)
        # Lokasi
        self.lokasi_label = tk.Label(self, text="Ekspor data lokasi")
        self.lokasi_label.grid(row=2, column=0)
        self.lokasi = tk.BooleanVar(self, value=True)
        self.lokasi_ya = tk.Radiobutton(
            self, text="Ya", variable=self.lokasi, value=True
        )
        self.lokasi_ya.grid(row=2, column=1)
        self.lokasi_tidak = tk.Radiobutton(
            self, text="Tidak", variable=self.lokasi, value=False
        )
        self.lokasi_tidak.grid(row=2, column=2)
        # Pendidikan
        self.pendidikan_label = tk.Label(self, text="Ekspor data pendidikan")
        self.pendidikan_label.grid(row=3, column=0)
        self.pendidikan = tk.BooleanVar(self, value=True)
        self.pendidikan_ya = tk.Radiobutton(
            self, text="Ya", variable=self.pendidikan, value=True
        )
        self.pendidikan_ya.grid(row=3, column=1)
        self.pendidikan_tidak = tk.Radiobutton(
            self, text="Tidak", variable=self.pendidikan, value=False
        )
        self.pendidikan_tidak.grid(row=3, column=2)
        # Kesehatan
        self.kesehatan_label = tk.Label(self, text="Ekspor data kesehatan")
        self.kesehatan_label.grid(row=4, column=0)
        self.kesehatan = tk.BooleanVar(self, value=True)
        self.kesehatan_ya = tk.Radiobutton(
            self, text="Ya", variable=self.kesehatan, value=True
        )
        self.kesehatan_ya.grid(row=4, column=1)
        self.kesehatan_tidak = tk.Radiobutton(
            self, text="Tidak", variable=self.kesehatan, value=False
        )
        self.kesehatan_tidak.grid(row=4, column=2)
        # Tenaga Kesehatan
        self.tenaga_kesehatan_label = tk.Label(
            self, text="Ekspor data tenaga kesehatan"
        )
        self.tenaga_kesehatan_label.grid(row=5, column=0)
        self.tenaga_kesehatan = tk.BooleanVar(self, value=True)
        self.tenaga_kesehatan_ya = tk.Radiobutton(
            self, text="Ya", variable=self.tenaga_kesehatan, value=True
        )
        self.tenaga_kesehatan_ya.grid(row=5, column=1)
        self.tenaga_kesehatan_tidak = tk.Radiobutton(
            self, text="Tidak", variable=self.tenaga_kesehatan, value=False
        )
        self.tenaga_kesehatan_tidak.grid(row=5, column=2)
        # Sarpras
        self.sarpras_label = tk.Label(self, text="Ekspor data sarpras")
        self.sarpras_label.grid(row=6, column=0)
        self.sarpras = tk.BooleanVar(self, value=True)
        self.sarpras_ya = tk.Radiobutton(
            self, text="Ya", variable=self.sarpras, value=True
        )
        self.sarpras_ya.grid(row=6, column=1)
        self.sarpras_tidak = tk.Radiobutton(
            self, text="Tidak", variable=self.sarpras, value=False
        )
        self.sarpras_tidak.grid(row=6, column=2)
        # Lain-lain
        self.lain_lain_label = tk.Label(self, text="Ekspor data lain_lain")
        self.lain_lain_label.grid(row=7, column=0)
        self.lain_lain = tk.BooleanVar(self, value=True)
        self.lain_lain_ya = tk.Radiobutton(
            self, text="Ya", variable=self.lain_lain, value=True
        )
        self.lain_lain_ya.grid(row=7, column=1)
        self.lain_lain_tidak = tk.Radiobutton(
            self, text="Tidak", variable=self.lain_lain, value=False
        )
        self.lain_lain_tidak.grid(row=7, column=2)
        self.info_label = tk.Label(
            self,
            text="Buat template dan isi dengan rt rw, dan no kk "
            "dari data yang ingin diekspor dari aplikasi!",
        )
        self.info_label.grid(row=8, column=0, columnspan=3)
        self.start_button = tk.Button(
            self,
            text="Pilih template keluarga dan mulai ekspor",
            command=self.export,
        )
        self.start_button.grid(row=9, column=0)

    def export(self):
        files = [
            ("Excel 2010+", "*.xlsx"),
        ]
        filepath = askopenfilename(filetypes=files, defaultextension=files)
        if not filepath:
            showwarning("Gagal", "Mohon pilih template yang benar")
            return
        try:
            _export_keluarga(
                filepath=filepath,
                ranges=self.baris.get(),
                row_pendidikan=2,
                row_kesehatan=2,
                row_tenaga_kesehatan=2,
                row_sarpras=2,
                skip_lokasi=not self.lokasi.get(),
                skip_pendidikan=not self.pendidikan.get(),
                skip_kesehatan=not self.kesehatan.get(),
                skip_tenaga_kesehatan=not self.tenaga_kesehatan.get(),
                skip_sarpras=not self.sarpras.get(),
                skip_lain_lain=not self.lain_lain.get(),
            )
        except FileNotFoundError:
            showwarning(
                "Gagal", "Gagal mengeksport data karena file template tidak ditemukan"
            )
        except Exception as e:
            showwarning("Error", f"Gagal mengeksport data keluarga karena {repr(e)}")

    @staticmethod
    def info_baris():
        showinfo(
            "Baris?",
            'Baris data dari template yang diambil datanya\nMisalnya "2-100,150-200"',
        )



MAPPING = {
    "desa": "desa",
    "I.P103": "nama",
    "I.P104": "jenis_kelamin",
    "I.P105": "tempat_lahir",
    "I.P106": "tanggal_lahir",
    "I.P107": "usia",
    "I.P108": "status_pernikahan",
    "I.P109": "usia_menikah",
    "I.P110": "agama",
    "I.P111": "suku_bangsa",
    "I.P112": "warga_negara",
    "I.P113": "nomor_hp",
    "I.P114": "nomor_whatsapp",
    "I.P115": "alamat_email",
    "I.P116": "alamat_facebook",
    "I.P117": "alamat_twitter",
    "I.P118": "alamat_instagram",
    "I.P119": "aktif_internet",
    "I.P120": "akses_melalui",
    "I.P121": "kecepatan_internet",
    "I.P201": "kondisi_pekerjaan",
    "I.P202": "pekerjaan_utama",
    "I.P202-Comment": "pekerjaan_utama_comment",
    "I.P203": "jaminan_sosial_ketenagakerjaan",
    "I.P204": "penghasilan",
    "I.P204_penghasilan": "pekerjaan_penghasilan",
    "I.P401": "penyakit_diderita",
    "I.P402": "fasilitas_kesehatan",
    "I.P403": "jamsos_ketenagakerjaan",
    "I.P404": "penyakit_diderita",
    "I.P405": "setahun_melahirkan",
    "I.P406": "mendapat_asi",
    "I.P501": "pendidikan_tertinggi",
    "I.P502": "tahun_pendidikan",
    "I.P505": "bahasa_permukiman",
    "I.P506": "bahasa_formal",
    "I.P507": "kerja_bakti",
    "I.P508": "siskamling",
    "I.P509": "pesta_rakyat",
    "I.P510": "menolong_kematian",
    "I.P511": "menolong_sakit",
    "I.P512": "menolong_kecelakaan",
    "I.P513": "memperoleh_pelayanan_desa",
    "I.P514": "pelayanan_desa",
    "I.P515": "saran_desa",
    "I.P516": "keterbukaan_desa",
    "I.P517": "terjadi_bencana",
    "I.P518": "terdampak_bencana",
    "kecamatan": "kecamatan",
    "kota": "kota",
    "nik": "nik",
    "no_kk": "no_kk",
    "provinsi": "provinsi",
    "rt": "rt",
    "rw": "rw",
}



import attr
from typing import Dict


@attr.dataclass
class PenyakitDiderita:
    # P404
    mutaber_diare: bool = False
    demam_berdarah: bool = False
    campak: bool = False
    malaria: bool = False
    flu_burung_sars: bool = False
    covid19: bool = False
    hepatitis_b: bool = False
    hepatitis_e: bool = False
    difteri: bool = False
    chikungunya: bool = False
    leptospirosis: bool = False
    kolera: bool = False
    gizi_buruk: bool = False
    jantung: bool = False
    tbc_paru_paru: bool = False
    kanker: bool = False
    diabetes: bool = False
    lumpuh: bool = False
    lainnya: bool = False

    def todict(self) -> Dict[str, str]:
        return {
            "1": "1" if self.mutaber_diare else "2",
            "2": "1" if self.demam_berdarah else "2",
            "3": "1" if self.campak else "2",
            "4": "1" if self.malaria else "2",
            "5": "1" if self.flu_burung_sars else "2",
            "6": "1" if self.covid19 else "2",
            "7": "1" if self.hepatitis_b else "2",
            "8": "1" if self.hepatitis_e else "2",
            "9": "1" if self.difteri else "2",
            "10": "1" if self.chikungunya else "2",
            "11": "1" if self.leptospirosis else "2",
            "12": "1" if self.kolera else "2",
            "13": "1" if self.gizi_buruk else "2",
            "14": "1" if self.jantung else "2",
            "15": "1" if self.tbc_paru_paru else "2",
            "16": "1" if self.kanker else "2",
            "17": "1" if self.diabetes else "2",
            "18": "1" if self.lumpuh else "2",
            "19": "1" if self.lainnya else "2",
        }



import cattr
from requests import Response, Session
from typing import Any, Dict

from . import DataIndividu
from . import DataKesehatan
from . import DataPekerjaan
from . import DataPenghasilan
from . import Penghasilan
from . import DataWilayah


cattr.register_unstructure_hook(DataIndividu, DataIndividu.todict)
cattr.register_unstructure_hook(DataKesehatan, DataKesehatan.todict)
cattr.register_unstructure_hook(DataPekerjaan, DataPekerjaan.todict)
cattr.register_unstructure_hook(DataPenghasilan, DataPenghasilan.todict)
cattr.register_unstructure_hook(Penghasilan, Penghasilan.todict)
cattr.register_unstructure_hook(DataWilayah, DataWilayah.todict)


def tambah_individu(
    session: Session,
    wilayah: DataWilayah,
    individu: DataIndividu,
    pekerjaan: DataPekerjaan,
    penghasilan: DataPenghasilan,
):
    data: Dict[str, Any] = dict()
    data.update(cattr.unstructure(wilayah))
    data.update(cattr.unstructure(individu))
    data.update(cattr.unstructure(pekerjaan))
    data.update(cattr.unstructure(penghasilan))
    # surveyIndividu/save
    return session.post(
        "https://sdgsdev.kemendesa.go.id/surveyIndividu/save",
        json=data,
    )



from .content import ContentFrame
from .sidebar import SidebarFrame

from .aplikasi import AplikasiTab

from .main import MainApp


__all__ = ["AplikasiTab", "ContentFrame", "SidebarFrame", "MainApp"]



import cattr
from typing import Optional

from .disabilitas import Disabilitas
from .fasilitas_kesehatan import FasilitasKesehatan
from .penyakit_diderita import PenyakitDiderita


__all__ = ["Disabilitas", "FasilitasKesehatan", "PenyakitDiderita"]

cattr.unstructure(Disabilitas, Disabilitas.todict)
cattr.unstructure(FasilitasKesehatan, FasilitasKesehatan.todict)
cattr.unstructure(PenyakitDiderita, PenyakitDiderita.todict)


class DataKesehatan:
    penyakit_diderita: PenyakitDiderita
    fasilitas_kesehatan: FasilitasKesehatan
    jamsos_kesehatan: str
    disabilitas: Disabilitas
    setahun_melahirkan: Optional[bool]
    mendapat_asi: Optional[bool]

    def todict(self):
        data = {
            "I.P401": cattr.unstructure(self.penyakit_diderita),
            "I.P402": cattr.unstructure(self.fasilitas_kesehatan),
            "I.P403": self.jamsos_kesehatan,
            "I.P404": cattr.unstructure(self.disabilitas),
            # "I.P405": "setahun_melahirkan",
            # "I.P406": "mendapat_asi",
        }

        if self.setahun_melahirkan is not None:
            data["I.P405"] = "1" if self.setahun_melahirkan else "2"
        if self.mendapat_asi is not None:
            data["I.P406"] = "1" if self.mendapat_asi else "2"
        return data



import attr
from typing import Dict


@attr.dataclass
class Disabilitas:
    tunanetra: bool = False
    tunarungu: bool = False
    tunawicara: bool = False
    tunarungu_wicara: bool = False
    tunadaksa: bool = False
    tunagrahita: bool = False
    tunalaras: bool = False
    cacat_eks_kusta: bool = False
    cacat_ganda: bool = False
    dipasung: bool = False

    def todict(self) -> Dict[str, str]:
        return {
            "1": "1" if self.tunanetra else "2",
            "2": "1" if self.tunarungu else "2",
            "3": "1" if self.tunawicara else "2",
            "4": "1" if self.tunarungu_wicara else "2",
            "5": "1" if self.tunadaksa else "2",
            "6": "1" if self.tunagrahita else "2",
            "7": "1" if self.tunalaras else "2",
            "8": "1" if self.cacat_eks_kusta else "2",
            "9": "1" if self.cacat_ganda else "2",
            "10": "1" if self.dipasung else "2",
        }



from .individu import DataIndividu
from .kesehatan import DataKesehatan
from .pekerjaan import DataPekerjaan
from .penghasilan import Penghasilan, DataPenghasilan
from .wilayah import DataWilayah

from .tambah import tambah_individu

__all__ = [
    "DataIndividu",
    "DataKesehatan",
    "DataPekerjaan",
    "DataPenghasilan",
    "DataWilayah",
    "Penghasilan",
    "tambah_individu",
]



import attr
from typing import Dict, List, Optional


@attr.dataclass
class Penghasilan:
    diekspor: str
    jumlah: str
    penghasilan: str
    sumber_penghasilan: str
    comment: Optional[str] = None

    def todict(self) -> Dict[str, str]:
        data: Dict[str, str] = {
            "diekspor": "diekspor",
            "jumlah": "jumlah",
            "penghasilan": "penghasilan",
            "sumber_penghasilan": "sumber_penghasilan",
        }
        if self.sumber_penghasilan == "other":
            if not self.comment:
                raise ValueError("comment harus diisi jika sumber_penghasilan = other")
            data["sumber_penghasilan-Comment"] = self.comment
        return data


@attr.dataclass
class DataPenghasilan:
    penghasilan: List[Penghasilan]
    pekerjaan_penghasilan: str

    def todict(self):
        return {
            "I.P204": [p.todict() for p in self.penghasilan],
            "I.P204_penghasilan": self.pekerjaan_penghasilan,
        }



import attr
from typing import Dict

MAPPING = {
    "1": "rumah_sakit",
    "2": "rumah_sakit_bersalin",
    "3": "puskesmas_rawat_inap",
    "4": "puskesmas_tanpa_inap",
    "5": "puskesmas_pembantu",
    "6": "poliklinik",
    "7": "tempat_praktik_dokter",
    "8": "rumah_bersalin",
    "9": "tempat_praktik_bidan",
    "10": "poskesdes",
    "11": "polindes",
    "12": "apotik",
    "13": "toko_obat_jamu",
    "14": "posyandu",
    "15": "posbindu",
    "16": "tempat_praktik_dukun",
}


@attr.dataclass
class FasilitasKesehatan:
    rumah_sakit: int
    rumah_sakit_bersalin: int
    puskesmas_rawat_inap: int
    puskesmas_tanpa_inap: int
    puskesmas_pembantu: int
    poliklinik: int
    tempat_praktik_dokter: int
    rumah_bersalin: int
    tempat_praktik_bidan: int
    poskesdes: int
    polindes: int
    apotik: int
    toko_obat_jamu: int
    posyandu: int
    posbindu: int
    tempat_praktik_dukun: int

    def todict(self) -> Dict[str, str]:
        data: Dict[str, str] = dict()
        for key, name in MAPPING.items():
            data["key"] = getattr(self, name, 0)
        return data
